@@ -1,6 +1,4 @@
-from django.conf import settings
 from django.conf.urls import patterns, include, url
-from django.conf.urls.static import static
 from django.contrib import admin
 from django.views.generic import TemplateView
 
@@ -8,10 +6,10 @@ admin.autodiscover()
 
 urlpatterns = patterns('',
     url(r'^admin/', include(admin.site.urls)),
-) + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
+)
 
 urlpatterns += patterns('',
-    url(r'^datamaps/', include('datamaps.urls')),
+    url(r'^datamaps/', include('core.urls')),
     url(r'^$', TemplateView.as_view(
         template_name="index.html")),
 )
\ No newline at end of file
