@@ -19,7 +19,7 @@ import os
 # if running multiple sites in the same mod_wsgi process. To fix this, use
 # mod_wsgi daemon mode with each site in its own daemon process, or use
 # os.environ["DJANGO_SETTINGS_MODULE"] = "pycharm.settings"
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "datamaps.tests.settings")
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "example.settings")
 
 # This application object is used by any WSGI server configured to use this
 # file. This includes Django's development server, if the WSGI_APPLICATION
